@@ -26,12 +26,12 @@
 
 This AWS Solutions Construct implements (1) an AWS Lambda function that is configured to send messages to a queue; (2) an Amazon SQS queue; and (3) an AWS Lambda function configured to consume messages from the queue.
 
-Here is a minimal deployable pattern definition:
+Here is a minimal deployable pattern definition in Typescript:
 
 ```javascript
-const { LambdaToSqsToLambda } = require('@aws-solutions-constructs/aws-lambda-sqs-lambda');
+import { LambdaToSqsToLambda, LambdaToSqsToLambdaProps } from "@aws-solutions-constructs/aws-lambda-sqs-lambda";
 
-new LambdaToSqsToLambda(stack, 'LambdaToSqsToLambdaPattern', {
+new LambdaToSqsToLambda(this, 'LambdaToSqsToLambdaPattern', {
     producerLambdaFunctionProps: {
         runtime: lambda.Runtime.NODEJS_12_X,
         handler: 'index.handler',
@@ -89,6 +89,7 @@ Out-of-the-box implementation of this Construct (without any overridden properti
 
 * Configure least privilege access IAM role for Lambda functions.
 * Enable reusing connections with Keep-Alive for NodeJs Lambda functions.
+* Enable X-Ray Tracing
 
 ### Amazon SQS Queue
 
@@ -112,8 +113,8 @@ import enum
 import typing
 
 import jsii
-import jsii.compat
 import publication
+import typing_extensions
 
 from ._jsii import *
 
@@ -135,24 +136,16 @@ class LambdaToSqsToLambda(
     def __init__(
         self,
         scope: aws_cdk.core.Construct,
-        id: str,
+        id: builtins.str,
         *,
-        consumer_lambda_function_props: typing.Optional[
-            aws_cdk.aws_lambda.FunctionProps
-        ] = None,
+        consumer_lambda_function_props: typing.Optional[aws_cdk.aws_lambda.FunctionProps] = None,
         dead_letter_queue_props: typing.Optional[aws_cdk.aws_sqs.QueueProps] = None,
-        deploy_dead_letter_queue: typing.Optional[bool] = None,
-        existing_consumer_lambda_obj: typing.Optional[
-            aws_cdk.aws_lambda.Function
-        ] = None,
-        existing_producer_lambda_obj: typing.Optional[
-            aws_cdk.aws_lambda.Function
-        ] = None,
+        deploy_dead_letter_queue: typing.Optional[builtins.bool] = None,
+        existing_consumer_lambda_obj: typing.Optional[aws_cdk.aws_lambda.Function] = None,
+        existing_producer_lambda_obj: typing.Optional[aws_cdk.aws_lambda.Function] = None,
         existing_queue_obj: typing.Optional[aws_cdk.aws_sqs.Queue] = None,
         max_receive_count: typing.Optional[jsii.Number] = None,
-        producer_lambda_function_props: typing.Optional[
-            aws_cdk.aws_lambda.FunctionProps
-        ] = None,
+        producer_lambda_function_props: typing.Optional[aws_cdk.aws_lambda.FunctionProps] = None,
         queue_props: typing.Optional[aws_cdk.aws_sqs.QueueProps] = None,
     ) -> None:
         """
@@ -189,22 +182,22 @@ class LambdaToSqsToLambda(
 
         jsii.create(LambdaToSqsToLambda, self, [scope, id, props])
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="consumerLambdaFunction")
     def consumer_lambda_function(self) -> aws_cdk.aws_lambda.Function:
         return jsii.get(self, "consumerLambdaFunction")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="producerLambdaFunction")
     def producer_lambda_function(self) -> aws_cdk.aws_lambda.Function:
         return jsii.get(self, "producerLambdaFunction")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="sqsQueue")
     def sqs_queue(self) -> aws_cdk.aws_sqs.Queue:
         return jsii.get(self, "sqsQueue")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="deadLetterQueue")
     def dead_letter_queue(self) -> typing.Optional[aws_cdk.aws_sqs.DeadLetterQueue]:
         return jsii.get(self, "deadLetterQueue")
@@ -229,22 +222,14 @@ class LambdaToSqsToLambdaProps:
     def __init__(
         self,
         *,
-        consumer_lambda_function_props: typing.Optional[
-            aws_cdk.aws_lambda.FunctionProps
-        ] = None,
+        consumer_lambda_function_props: typing.Optional[aws_cdk.aws_lambda.FunctionProps] = None,
         dead_letter_queue_props: typing.Optional[aws_cdk.aws_sqs.QueueProps] = None,
-        deploy_dead_letter_queue: typing.Optional[bool] = None,
-        existing_consumer_lambda_obj: typing.Optional[
-            aws_cdk.aws_lambda.Function
-        ] = None,
-        existing_producer_lambda_obj: typing.Optional[
-            aws_cdk.aws_lambda.Function
-        ] = None,
+        deploy_dead_letter_queue: typing.Optional[builtins.bool] = None,
+        existing_consumer_lambda_obj: typing.Optional[aws_cdk.aws_lambda.Function] = None,
+        existing_producer_lambda_obj: typing.Optional[aws_cdk.aws_lambda.Function] = None,
         existing_queue_obj: typing.Optional[aws_cdk.aws_sqs.Queue] = None,
         max_receive_count: typing.Optional[jsii.Number] = None,
-        producer_lambda_function_props: typing.Optional[
-            aws_cdk.aws_lambda.FunctionProps
-        ] = None,
+        producer_lambda_function_props: typing.Optional[aws_cdk.aws_lambda.FunctionProps] = None,
         queue_props: typing.Optional[aws_cdk.aws_sqs.QueueProps] = None,
     ) -> None:
         """
@@ -262,24 +247,16 @@ class LambdaToSqsToLambdaProps:
         :summary:: The properties for the LambdaToSqsToLambda class.
         """
         if isinstance(consumer_lambda_function_props, dict):
-            consumer_lambda_function_props = aws_cdk.aws_lambda.FunctionProps(
-                **consumer_lambda_function_props
-            )
+            consumer_lambda_function_props = aws_cdk.aws_lambda.FunctionProps(**consumer_lambda_function_props)
         if isinstance(dead_letter_queue_props, dict):
-            dead_letter_queue_props = aws_cdk.aws_sqs.QueueProps(
-                **dead_letter_queue_props
-            )
+            dead_letter_queue_props = aws_cdk.aws_sqs.QueueProps(**dead_letter_queue_props)
         if isinstance(producer_lambda_function_props, dict):
-            producer_lambda_function_props = aws_cdk.aws_lambda.FunctionProps(
-                **producer_lambda_function_props
-            )
+            producer_lambda_function_props = aws_cdk.aws_lambda.FunctionProps(**producer_lambda_function_props)
         if isinstance(queue_props, dict):
             queue_props = aws_cdk.aws_sqs.QueueProps(**queue_props)
-        self._values = {}
+        self._values: typing.Dict[str, typing.Any] = {}
         if consumer_lambda_function_props is not None:
-            self._values[
-                "consumer_lambda_function_props"
-            ] = consumer_lambda_function_props
+            self._values["consumer_lambda_function_props"] = consumer_lambda_function_props
         if dead_letter_queue_props is not None:
             self._values["dead_letter_queue_props"] = dead_letter_queue_props
         if deploy_dead_letter_queue is not None:
@@ -293,9 +270,7 @@ class LambdaToSqsToLambdaProps:
         if max_receive_count is not None:
             self._values["max_receive_count"] = max_receive_count
         if producer_lambda_function_props is not None:
-            self._values[
-                "producer_lambda_function_props"
-            ] = producer_lambda_function_props
+            self._values["producer_lambda_function_props"] = producer_lambda_function_props
         if queue_props is not None:
             self._values["queue_props"] = queue_props
 
@@ -311,7 +286,8 @@ class LambdaToSqsToLambdaProps:
         default
         :default: - Default properties are used.
         """
-        return self._values.get("consumer_lambda_function_props")
+        result = self._values.get("consumer_lambda_function_props")
+        return result
 
     @builtins.property
     def dead_letter_queue_props(self) -> typing.Optional[aws_cdk.aws_sqs.QueueProps]:
@@ -323,10 +299,11 @@ class LambdaToSqsToLambdaProps:
         default
         :default: - Default props are used.
         """
-        return self._values.get("dead_letter_queue_props")
+        result = self._values.get("dead_letter_queue_props")
+        return result
 
     @builtins.property
-    def deploy_dead_letter_queue(self) -> typing.Optional[bool]:
+    def deploy_dead_letter_queue(self) -> typing.Optional[builtins.bool]:
         """Whether to create a secondary queue to be used as a dead letter queue.
 
         Defaults to ``true``.
@@ -334,7 +311,8 @@ class LambdaToSqsToLambdaProps:
         default
         :default: - true.
         """
-        return self._values.get("deploy_dead_letter_queue")
+        result = self._values.get("deploy_dead_letter_queue")
+        return result
 
     @builtins.property
     def existing_consumer_lambda_obj(
@@ -347,7 +325,8 @@ class LambdaToSqsToLambdaProps:
         default
         :default: - None.
         """
-        return self._values.get("existing_consumer_lambda_obj")
+        result = self._values.get("existing_consumer_lambda_obj")
+        return result
 
     @builtins.property
     def existing_producer_lambda_obj(
@@ -360,7 +339,8 @@ class LambdaToSqsToLambdaProps:
         default
         :default: - None.
         """
-        return self._values.get("existing_producer_lambda_obj")
+        result = self._values.get("existing_producer_lambda_obj")
+        return result
 
     @builtins.property
     def existing_queue_obj(self) -> typing.Optional[aws_cdk.aws_sqs.Queue]:
@@ -372,7 +352,8 @@ class LambdaToSqsToLambdaProps:
         default
         :default: - None.
         """
-        return self._values.get("existing_queue_obj")
+        result = self._values.get("existing_queue_obj")
+        return result
 
     @builtins.property
     def max_receive_count(self) -> typing.Optional[jsii.Number]:
@@ -386,7 +367,8 @@ class LambdaToSqsToLambdaProps:
         -
           15.
         """
-        return self._values.get("max_receive_count")
+        result = self._values.get("max_receive_count")
+        return result
 
     @builtins.property
     def producer_lambda_function_props(
@@ -400,7 +382,8 @@ class LambdaToSqsToLambdaProps:
         default
         :default: - Default properties are used.
         """
-        return self._values.get("producer_lambda_function_props")
+        result = self._values.get("producer_lambda_function_props")
+        return result
 
     @builtins.property
     def queue_props(self) -> typing.Optional[aws_cdk.aws_sqs.QueueProps]:
@@ -412,12 +395,13 @@ class LambdaToSqsToLambdaProps:
         default
         :default: - Default props are used.
         """
-        return self._values.get("queue_props")
+        result = self._values.get("queue_props")
+        return result
 
-    def __eq__(self, rhs) -> bool:
+    def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-    def __ne__(self, rhs) -> bool:
+    def __ne__(self, rhs: typing.Any) -> builtins.bool:
         return not (rhs == self)
 
     def __repr__(self) -> str:
